# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_joshuto_global_optspecs
	string join \n v/version change-directory file-chooser output-file= h/help
end

function __fish_joshuto_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_joshuto_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_joshuto_using_subcommand
	set -l cmd (__fish_joshuto_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c joshuto -n "__fish_joshuto_needs_command" -l output-file -r -F
complete -c joshuto -n "__fish_joshuto_needs_command" -s v -l version
complete -c joshuto -n "__fish_joshuto_needs_command" -l change-directory
complete -c joshuto -n "__fish_joshuto_needs_command" -l file-chooser
complete -c joshuto -n "__fish_joshuto_needs_command" -s h -l help -d 'Print help'
complete -c joshuto -n "__fish_joshuto_needs_command" -a "completions" -d 'Print completions for a given shell'
complete -c joshuto -n "__fish_joshuto_needs_command" -a "config" -d 'Print embedded toml configuration for a given config type'
complete -c joshuto -n "__fish_joshuto_needs_command" -a "version" -d 'Print \'joshuto\' build version'
complete -c joshuto -n "__fish_joshuto_needs_command" -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c joshuto -n "__fish_joshuto_using_subcommand completions" -s h -l help -d 'Print help'
complete -c joshuto -n "__fish_joshuto_using_subcommand config" -s h -l help -d 'Print help'
complete -c joshuto -n "__fish_joshuto_using_subcommand version" -s h -l help -d 'Print help'
complete -c joshuto -n "__fish_joshuto_using_subcommand help; and not __fish_seen_subcommand_from completions config version help" -f -a "completions" -d 'Print completions for a given shell'
complete -c joshuto -n "__fish_joshuto_using_subcommand help; and not __fish_seen_subcommand_from completions config version help" -f -a "config" -d 'Print embedded toml configuration for a given config type'
complete -c joshuto -n "__fish_joshuto_using_subcommand help; and not __fish_seen_subcommand_from completions config version help" -f -a "version" -d 'Print \'joshuto\' build version'
complete -c joshuto -n "__fish_joshuto_using_subcommand help; and not __fish_seen_subcommand_from completions config version help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
